@@ -4,6 +4,8 @@
 #undef HAVE_MMAP
 #undef HAVE_STRSEP
 #undef HAVE_STRTOK_R
+#undef HAVE_SIGACTION
+#undef HAVE_WAITPID
 #undef HAVE_LIBSM
 #undef HAVE_LC_MESSAGES
 #undef HAVE_STPCPY
@@ -12,4 +14,4 @@
 #undef HAVE_GETTEXT
 
 #define DIFF_PATH  "/usr/bin/diff"
-
+#define DIFF3_PATH  "/usr/bin/diff3"
