@@ -13,26 +13,25 @@ extern "C" {
 #endif /* __cplusplus */
 
 
-/* Contant numbers */
+/* Constant numbers */
 typedef enum {
 	REGULARFILE,
 	DIRECTORY,
-	OTHERFILE,
+	OTHERFILE
 } FileType;
 	
 
 /* Global function declarations */
 /* misc.c */
-extern inline const char* skip_n_lines(const char *ptr, int nl, int lenb);
 extern FileType check_filetype(const char *fname);
-extern int get_num_chars(const char *src, int lenb);
+extern int get_num_chars(const char *src, int lenb, int f_sbcs);
 extern int calc_number_places(int n);
-extern void get_file_name(char *fname, const char *fpath);
+extern char* get_file_name(char *fpath);
+extern char* get_rel_file_name(char *fpath, int dirlen);
 extern void close_allfd_except_std(void);
-extern void def_signal_handler(int sig);
 
 /* spawn.c */
-extern FILE* spawn_diff(char *prog, char *args, char *path1, char *path2);
+extern FILE* spawn_prog(char *prog, char *args, char *path1, char *path2, char *path3);
 
 #ifdef __cplusplus
 } 
