@@ -6,14 +6,13 @@
 #ifndef __GDIFF_RMENU_H__
 #define __GDIFF_RMENU_H__
 
-
 #ifdef __cplusplus 
 extern "C" {
 #endif /* __cplusplus */
 
 
 /* Global function declarations */
-extern void rmenu_create(GDiffFileViews *gfileviews);
+extern GtkWidget* rmenu_create(const GtkWidget *fview, gpointer data);
 
 #ifdef __cplusplus
 } 
